@@ -4,18 +4,20 @@ from elf_to_shellcode.elf_to_shellcode.lib.ext.irelative_relocations import Irel
 
 
 class IntelX64Shellcode(Shellcode):
-    def __init__(self, elffile, shellcode_data, endian):
+    def __init__(self, elffile, shellcode_data, endian, **kwargs):
         super(IntelX64Shellcode, self).__init__(
             elffile=elffile,
             shellcode_data=shellcode_data,
             endian=endian,
-            mini_loader_little_endian="mini_loader_x64.shellcode",
+            arch="x64",
+            mini_loader_little_endian="mini_loader_x64{}.shellcode",
             mini_loader_big_endian=None,
             shellcode_table_magic=0x8899aabbccddeeff,
             ptr_fmt="Q",
             sections_to_relocate={
                 '.data.rel.ro': {'align_by': 'sh_addralign'},
-            }
+            },
+            **kwargs
         )
         self.irelative = IrelativeRelocs(ENUM_RELOC_TYPE_x64['R_X86_64_IRELATIVE'])
         self.add_relocation_handler(self.irelative.relocation_for_rela_plt_got_plt)
